import { Menu } from './../index';
import { Animation, MenuCheckMode, MenuCloseAction, MenuDropDownPosition, MenuMode, Overflow, MenuSelectionMode } from './../index';
import { AfterViewInit, ElementRef, OnInit, OnChanges, OnDestroy, SimpleChanges, EventEmitter } from '@angular/core';
import { BaseElement } from './smart.element';
import * as i0 from "@angular/core";
export { Animation, MenuCheckMode, MenuCloseAction, MenuDropDownPosition, MenuMode, Overflow, MenuSelectionMode, ElementRenderMode } from './../index';
export { Smart } from './smart.element';
export { Menu } from './../index';
export declare class MenuComponent extends BaseElement implements OnInit, AfterViewInit, OnDestroy, OnChanges {
    constructor(ref: ElementRef<Menu>);
    private eventHandlers;
    nativeElement: Menu;
    /** @description Creates the component on demand.
     * @param properties An optional object of properties, which will be added to the template binded ones.
     */
    createComponent(properties?: {}): any;
    /** @description Sets or gets the animation mode. Animation is disabled when the property is set to 'none' */
    get animation(): Animation | string;
    set animation(value: Animation | string);
    /** @description Determines delay (in milliseconds) before a Menu dropdown is closed when leaving the Menu with the mouse. Applicable only when selectionMode is 'mouseenter'. */
    get autoCloseDelay(): number;
    set autoCloseDelay(value: number);
    /** @description If set to true, on mouseenter, the element receives focus automatically. */
    get autoFocusOnMouseenter(): boolean;
    set autoFocusOnMouseenter(value: boolean);
    /** @description Allows top-level Menu items (immediate children of the Menu) to be checkable. Sublevels are controlled by setting checkable to the respective smart-menu-items-group. */
    get checkable(): boolean;
    set checkable(value: boolean);
    /** @description Sets or gets whether checkboxes and radio buttons can be displayed in the Menu. This property is applicable only to the Menu itself, and not its smart-menu-item/smart-menu-items-group subitems. See also the property checkable. */
    get checkboxes(): boolean;
    set checkboxes(value: boolean);
    /** @description Sets the check mode of top-level Menu items (immediate children of the Menu). checkMode can be set to 'checkbox', 'radioButton', or a comma-separated list containing 'checkbox', 'radioButton', or 'none' (e.g. 'checkbox, radioButton, none, checkbox'). When set to a list, each value in the list is applied to groups of Menu items separated by an item with separator (item after the one with separator is the start of a new checkMode context). Sublevels are controlled by setting checkMode to the respective smart-menu-items-group. */
    get checkMode(): MenuCheckMode | string;
    set checkMode(value: MenuCheckMode | string);
    /** @description Sets the document event which closes any open Menu drop downs (or the Menu itself when mode is 'dropDown'). */
    get closeAction(): MenuCloseAction | string;
    set closeAction(value: MenuCloseAction | string);
    /** @description Determines the data source that will be loaded to the Menu. The data source represents an array of objects with the following properties: label - a string representing the text content of the item.value - the value of the item.shortcut - a string representing a shortuct for the item. It will be displayed inside the item.items - allows to define an array of sub menu items. */
    get dataSource(): any;
    set dataSource(value: any);
    /** @description Enables or disables element. */
    get disabled(): boolean;
    set disabled(value: boolean);
    /** @description Determines the field in the data source that corresponds to an item's label. */
    get displayMember(): string;
    set displayMember(value: string);
    /** @description Sets custom outer container, where all dropdown containers must be appended. By default they are inside the menu. The value of the property can be an HTML element or the id of an HTML element. In mode 'dropDown', the property dropDownAppendTo also controls the parent element of the whole Menu. The open method works relatively to the original place of the Menu in the DOM. */
    get dropDownAppendTo(): string | HTMLElement;
    set dropDownAppendTo(value: string | HTMLElement);
    /** @description If this property is enabled, when an element's dropdown is opened, a transparent overlay is positioned between the dropdown and the rest of the document. */
    get dropDownOverlay(): boolean;
    set dropDownOverlay(value: boolean);
    /** @description Determines the opening direction of Menu dropdowns. */
    get dropDownPosition(): MenuDropDownPosition | string;
    set dropDownPosition(value: MenuDropDownPosition | string);
    /** @description A getter that returns an array of all Menu items. */
    get items(): any;
    set items(value: any);
    /** @description Determines the field in the data source that corresponds to an item group's subitems collection. */
    get itemsMember(): string;
    set itemsMember(value: string);
    /** @description Sets or gets the unlockKey which unlocks the product. */
    get unlockKey(): string;
    set unlockKey(value: string);
    /** @description Sets or gets the language. Used in conjunction with the property messages.  */
    get locale(): string;
    set locale(value: string);
    /** @description Callback used to customize the format of the messages that are returned from the Localization Module. */
    get localizeFormatFunction(): any;
    set localizeFormatFunction(value: any);
    /** @description Sets or gets an object specifying strings used in the widget that can be localized. Used in conjunction with the property locale.  */
    get messages(): any;
    set messages(value: any);
    /** @description Used to load a custom minimize icon from an HTMLTemplateElement object. The HTMLTemplateElement is selected by it's id. */
    get minimizeIconTemplate(): string;
    set minimizeIconTemplate(value: string);
    /** @description Determines the minimum width of the Menu at which it will switch from normal to minimized mode. If set to null, the Menu does not minimize automatically. */
    get minimizeWidth(): number;
    set minimizeWidth(value: number);
    /** @description Determines the menu's display mode. */
    get mode(): MenuMode | string;
    set mode(value: MenuMode | string);
    /** @description Opens or closes thte menu when it's in 'dropDown' mode. */
    get opened(): boolean;
    set opened(value: boolean);
    /** @description Sets or gets the menu's scroll buttons behavior. Applicable only when dropDownAppendTo is not null. */
    get overflow(): Overflow | string;
    set overflow(value: Overflow | string);
    /** @description If set to true, prevents the closing of the Menu or its dropdowns when Menu items are checked/unchecked. */
    get preventCloseOnCheck(): boolean;
    set preventCloseOnCheck(value: boolean);
    /** @description If the element is readonly, users cannot interact with it. */
    get readonly(): boolean;
    set readonly(value: boolean);
    /** @description Sets or gets the value indicating whether the element is aligned to support locales using right-to-left fonts. */
    get rightToLeft(): boolean;
    set rightToLeft(value: boolean);
    /** @description Determines the menu's selection mode. */
    get selectionMode(): MenuSelectionMode | string;
    set selectionMode(value: MenuSelectionMode | string);
    /** @description Determines the theme. Theme defines the look of the element */
    get theme(): string;
    set theme(value: string);
    /** @description If is set to true, the element cannot be focused. */
    get unfocusable(): boolean;
    set unfocusable(value: boolean);
    /** @description Determines the field in the data source that corresponds to an item's value. */
    get valueMember(): string;
    set valueMember(value: string);
    /** @description This event is triggered when the menu is closed. The event is fired only in 'dropDown' mode.
    *  @param event. The custom event. 	*/
    onClose: EventEmitter<CustomEvent>;
    /** @description This event is triggered when the menu is about to be closed. The closing operation can be canceled by calling event.preventDefault() in the event handler function. The event is fired only in 'dropDown' mode.
    *  @param event. The custom event. 	Custom event was created with: event.detail(	trigger)
    *   trigger - Indicates whether the event was called from inside the element or programatically.
    */
    onClosing: EventEmitter<CustomEvent>;
    /** @description This event is triggered when a smart-menu-items-group is collapsed.
    *  @param event. The custom event. 	Custom event was created with: event.detail(	item, 	label, 	value, 	path, 	children)
    *   item - The menu item that was collapsed.
    *   label - The label of the toggled item that was collapsed.
    *   value - The value of the toggled item that was collapsed.
    *   path - The path of the toggled item that was collapsed, e.g. '0.1', '1.1.2'.
    *   children - The children items of the toggled item that was collapsed.
    */
    onCollapse: EventEmitter<CustomEvent>;
    /** @description This event is triggered when a smart-menu-items-group is collapsing.
    *  @param event. The custom event. 	Custom event was created with: event.detail(	item, 	label, 	value, 	path, 	children)
    *   item - The menu item that is going to be collapsed.
    *   label - The label of the toggled item that is going to be collapsed.
    *   value - The value of the toggled item that is going to be collapsed.
    *   path - The path of the toggled item that is going to be collapsed, e.g. '0.1', '1.1.2'.
    *   children - The children items of the toggled item that is going to be collapsed.
    */
    onCollapsing: EventEmitter<CustomEvent>;
    /** @description This event is triggered when a smart-menu-items-group is expanded.
    *  @param event. The custom event. 	Custom event was created with: event.detail(	item, 	label, 	value, 	path, 	children)
    *   item - The menu item that was expanded.
    *   label - The label of the toggled item that was expanded.
    *   value - The value of the toggled item that was expanded.
    *   path - The path of the toggled item that was expanded, e.g. '0.1', '1.1.2'.
    *   children - The children items of the toggled item that was expanded.
    */
    onExpand: EventEmitter<CustomEvent>;
    /** @description This event is triggered before a smart-menu-items-group is expanded.
    *  @param event. The custom event. 	Custom event was created with: event.detail(	item, 	label, 	value, 	path, 	children)
    *   item - The menu item that is going to be expanded.
    *   label - The label of the toggled item that is going to be expanded.
    *   value - The value of the toggled item that is going to be expanded.
    *   path - The path of the toggled item that is going to be expanded, e.g. '0.1', '1.1.2'.
    *   children - The children items of the toggled item that is going to be expanded.
    */
    onExpanding: EventEmitter<CustomEvent>;
    /** @description This event is triggered when a menu item check state is changed.
    *  @param event. The custom event. 	Custom event was created with: event.detail(	item, 	label, 	value, 	checked)
    *   item - The menu item which state was changed.
    *   label - The label of the item which state was changed.
    *   value - The value of the item which state was changed.
    *   checked - The checked state of the toggled item. If false the item is not toggled.
    */
    onItemCheckChange: EventEmitter<CustomEvent>;
    /** @description This event is triggered when a menu item is clicked.
    *  @param event. The custom event. 	Custom event was created with: event.detail(	item, 	label, 	value)
    *   item - The menu item that is toggled.
    *   label - The label of the toggled item.
    *   value - The value of the toggled item.
    */
    onItemClick: EventEmitter<CustomEvent>;
    /** @description This event is triggered when the menu is opened. The event is fired only in 'dropDown' mode.
    *  @param event. The custom event. 	*/
    onOpen: EventEmitter<CustomEvent>;
    /** @description This event is triggered when the menu is about to be opened. The opening operation can be canceled by calling event.preventDefault() in the event handler function. The event is fired only in 'dropDown' mode.
    *  @param event. The custom event. 	*/
    onOpening: EventEmitter<CustomEvent>;
    /** @description Adds an item to the menu.
    * @param {HTMLElement} Item. A smart-menu-item to add to the Menu.
    * @param {HTMLElement | string} Parent?. The smart-menu-items-group or its id or numeric path to add the item to.
    */
    addItem(Item: HTMLElement, Parent?: HTMLElement | string): void;
    /** @description Checks an item.
    * @param {HTMLElement | string} item. smart-menu-item/smart-menu-items-group or its id or numeric path.
    */
    checkItem(item: HTMLElement | string): void;
    /** @description Clears all Menu items.
    */
    clear(): void;
    /** @description Clicks on an item programatically.
    * @param {HTMLElement | string} item. smart-menu-item/smart-menu-items-group or its id or numeric path.
    */
    clickItem(item: HTMLElement | string): void;
    /** @description Closes the Menu when mode is 'dropDown'.
    */
    close(): void;
    /** @description Collapses an item.
    * @param {HTMLElement | string} item?. smart-menu-item/smart-menu-items-group or its id or numeric path. If no item is passed, all open items are collapsed.
    * @param {boolean} animation?. If set to false, disables collapse animation even if animation is enabled for the element.
    */
    collapseItem(item?: HTMLElement | string, animation?: boolean): void;
    /** @description Expands an item.
    * @param {HTMLElement | string} item. smart-menu-item/smart-menu-items-group or its id or numeric path.
    * @param {boolean} animation?. If set to false, disables expand animation even if animation is enabled for the element.
    */
    expandItem(item: HTMLElement | string, animation?: boolean): void;
    /** @description Gets an item by its id or numeric path.
    * @param {string} id. The id or numeric path of an item
    * @returns {HTMLElement}
  */
    getItem(id: any): Promise<any>;
    /** @description Maximizes the Menu.
    */
    maximize(): void;
    /** @description Minimizes the Menu.
    */
    minimize(): void;
    /** @description Opens the Menu when mode is 'dropDown'.
    * @param {number} left. Horizontal position
    * @param {number} top. Vertical position
    */
    open(left: number, top: number): void;
    /** @description Removes an item from the menu.
    * @param {HTMLElement | string} item. The smart-menu-item/smart-menu-items-group or its id or numeric path to remove.
    */
    removeItem(item: HTMLElement | string): void;
    /** @description Unchecks an item.
    * @param {HTMLElement | string} item. smart-menu-item/smart-menu-items-group (or its id or numeric path)
    */
    uncheckItem(item: HTMLElement | string): void;
    get isRendered(): boolean;
    ngOnInit(): void;
    ngAfterViewInit(): void;
    ngOnDestroy(): void;
    ngOnChanges(changes: SimpleChanges): void;
    /** @description Add event listeners. */
    private listen;
    /** @description Remove event listeners. */
    private unlisten;
    static ɵfac: i0.ɵɵFactoryDeclaration<MenuComponent, never>;
    static ɵdir: i0.ɵɵDirectiveDeclaration<MenuComponent, "smart-menu, [smart-menu]", ["smart-menu"], { "animation": "animation"; "autoCloseDelay": "autoCloseDelay"; "autoFocusOnMouseenter": "autoFocusOnMouseenter"; "checkable": "checkable"; "checkboxes": "checkboxes"; "checkMode": "checkMode"; "closeAction": "closeAction"; "dataSource": "dataSource"; "disabled": "disabled"; "displayMember": "displayMember"; "dropDownAppendTo": "dropDownAppendTo"; "dropDownOverlay": "dropDownOverlay"; "dropDownPosition": "dropDownPosition"; "items": "items"; "itemsMember": "itemsMember"; "unlockKey": "unlockKey"; "locale": "locale"; "localizeFormatFunction": "localizeFormatFunction"; "messages": "messages"; "minimizeIconTemplate": "minimizeIconTemplate"; "minimizeWidth": "minimizeWidth"; "mode": "mode"; "opened": "opened"; "overflow": "overflow"; "preventCloseOnCheck": "preventCloseOnCheck"; "readonly": "readonly"; "rightToLeft": "rightToLeft"; "selectionMode": "selectionMode"; "theme": "theme"; "unfocusable": "unfocusable"; "valueMember": "valueMember"; }, { "onClose": "onClose"; "onClosing": "onClosing"; "onCollapse": "onCollapse"; "onCollapsing": "onCollapsing"; "onExpand": "onExpand"; "onExpanding": "onExpanding"; "onItemCheckChange": "onItemCheckChange"; "onItemClick": "onItemClick"; "onOpen": "onOpen"; "onOpening": "onOpening"; }, never>;
}
